==> spip_3.0.18.orig.tar.xz: spip/ecrire/lang/public_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Degemer al lec’hienn', # MODIF
	'articles' => '@nb@ pennad',
	'articles_auteur' => 'Pennadoù all ar skridaozer-mañ',
	'articles_populaires' => 'Pennadoù lennet ar muiañ',
	'articles_rubrique' => 'Pennadoù ar rubrikenn-mañ',
	'aucun_article' => 'N’eus pennad ebet er chomlec’h-mañ',
	'aucun_auteur' => 'N’eus skridaozer ebet er chomlec’h-mañ',
	'aucun_site' => 'N’eus lec’hienn ebet er chomlec’h-mañ',
	'aucune_breve' => 'N’eus berrskrid ebet er chomlec’h-mañ',
	'aucune_rubrique' => 'N’eus rubrikenn ebet er chomlec’h-mañ',
	'autres' => 'Re all',
	'autres_breves' => 'Berrskridoù all',
	'autres_groupes_mots_clefs' => 'Strolladoù gerioù-stur all',
	'autres_sites' => 'Lec’hiennoù all',

	// B
	'bonjour' => 'Demat deoc’h',

	// C
	'commenter_site' => 'Ober evezhiadennoù diwar-benn al lec’hienn-mañ',
	'copie_document_impossible' => 'N’eo ket posupl eilañ an teul',

	// D
	'date' => 'Deiziad',
	'dernier_ajout' => 'Ouzhpennadenn ziwezhañ',
	'dernieres_breves' => 'Berrskridoù diwezhañ',
	'derniers_articles' => 'Pennadoù diwezhañ',
	'derniers_commentaires' => 'Evezhiadennoù diwezhañ',
	'derniers_messages_forum' => 'Kemennadennoù diwezhañ embannet er foromoù',

	// E
	'edition_mode_texte' => 'Aozañ e mod testenn',
	'en_reponse' => 'O respont da :',
	'en_resume' => 'Berr-ha-berr',
	'envoyer_message' => 'Kas ur gemennadenn',
	'espace_prive' => 'Lodenn brevez',

	// F
	'formats_acceptes' => 'Furmadoù aotreet : @formats@.',

	// H
	'hierarchie_site' => 'Gwezennadur al lec’hienn',

	// J
	'jours' => 'deizioù',

	// L
	'lien_connecter' => 'Kevreañ',

	// M
	'meme_auteur' => 'Gant ar skridaozer-mañ',
	'meme_rubrique' => 'Er rubrikenn-mañ',
	'memes_auteurs' => 'Gant ar skridaozerien-mañ',
	'message' => 'Kemennadenn',
	'messages_forum' => 'Kemennadennoù forom', # MODIF
	'messages_recents' => 'Kemennadennoù forom diwezhañ',
	'mots_clefs' => 'Gerioù-stur',
	'mots_clefs_meme_groupe' => 'Gerioù-stur er strollad-mañ',

	// N
	'navigation' => 'Merdeiñ',
	'nom' => 'Anv',
	'nouveautes' => 'Nevezinti',
	'nouveautes_web' => 'Nevezinti war ar gwiad',
	'nouveaux_articles' => 'Pennadoù nevez',
	'nouvelles_breves' => 'Berrskridoù nevez',

	// P
	'page_precedente' => 'Pajenn kent',
	'page_suivante' => 'Pajenn war-lerc’h',
	'par_auteur' => 'gant',
	'participer_site' => 'Gallout a rit kemer perzh e buhez al lec’hienn ha kinnig pennadoù oc’h emezelañ amañ dindan. Diouzhtu e vo kaset ur postel deoc’h, ennañ ar c’hodoù ret evit dont-tre.',
	'plan_site' => 'Steuñv al lec’hienn',
	'popularite' => 'Brud vat',
	'poster_message' => 'Kas ur gemennadenn',
	'proposer_site' => 'Gallout a rit kinnig ul lec’hienn da ouzhpennañ er rubrikenn-mañ :',

	// R
	'repondre_article' => 'Respont d’ar pennad-mañ',
	'repondre_breve' => 'Respont d’ar berrskrid-mañ',
	'resultats_recherche' => 'Disoc’hoù an enklask',
	'retour_debut_forums' => 'Distreiñ e deroù ar foromoù',
	'rubrique' => 'Rubrikenn',
	'rubriques' => 'Rubrikennoù',

	// S
	'signatures_petition' => 'Sinadurioù',
	'site_realise_avec_spip' => 'Lec’hienn bet savet gant SPIP',
	'sites_web' => 'Lec’hiennoù',
	'sous_rubriques' => 'Isrummadoù',
	'spam' => 'Strob',
	'suite' => 'kenderc’hel',
	'sur_web' => 'War ar Gwiad',
	'syndiquer_rubrique' => 'Sindikadañ ar rubrikenn-mañ',
	'syndiquer_site' => 'Sindikadañ al lec’hienn a-bezh',

	// T
	'texte_lettre_information' => 'Setu lizher kelaouiñ al lec’hienn',
	'texte_lettre_information_2' => 'Enni emañ ar pennadoù hag ar berrskridoù embannet abaoe', # MODIF

	// V
	'ver_imprimer' => 'Stumm da voullañ',
	'voir_en_ligne' => 'Gwelet enlinenn',
	'voir_squelette' => 'Gwelet framm ar bajenn-mañ'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/ecrire/lang/public_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Degemer al lec’hienn',
	'article' => 'Pennad-skrid',
	'articles' => '@nb@ pennad',
	'articles_auteur' => 'Pennadoù all ar skridaozer-mañ',
	'articles_populaires' => 'Pennadoù lennet ar muiañ',
	'articles_rubrique' => 'Pennadoù ar rubrikenn-mañ',
	'aucun_article' => 'N’eus pennad ebet er chomlec’h-mañ',
	'aucun_auteur' => 'N’eus skridaozer ebet er chomlec’h-mañ',
	'aucun_site' => 'N’eus lec’hienn ebet er chomlec’h-mañ',
	'aucune_breve' => 'N’eus berrskrid ebet er chomlec’h-mañ',
	'aucune_rubrique' => 'N’eus rubrikenn ebet er chomlec’h-mañ',
	'auteur' => 'Aozer',
	'autres' => 'Re all',
	'autres_breves' => 'Berrskridoù all',
	'autres_groupes_mots_clefs' => 'Strolladoù gerioù-stur all',
	'autres_sites' => 'Lec’hiennoù all',

	// B
	'bonjour' => 'Demat deoc’h',

	// C
	'commenter_site' => 'Ober evezhiadennoù diwar-benn al lec’hienn-mañ',
	'contact' => 'Darempred',
	'copie_document_impossible' => 'N’eo ket posupl eilañ an teul',

	// D
	'date' => 'Deiziad',
	'dernier_ajout' => 'Ouzhpennadenn ziwezhañ',
	'dernieres_breves' => 'Berrskridoù diwezhañ',
	'derniers_articles' => 'Pennadoù diwezhañ',
	'derniers_commentaires' => 'Evezhiadennoù diwezhañ',
	'derniers_messages_forum' => 'Kemennadennoù diwezhañ embannet er foromoù',

	// E
	'edition_mode_texte' => 'Aozañ e mod testenn',
	'en_reponse' => 'O respont da :',
	'en_resume' => 'Berr-ha-berr',
	'envoyer_message' => 'Kas ur gemennadenn',
	'espace_prive' => 'Lodenn brevez',

	// F
	'formats_acceptes' => 'Furmadoù aotreet : @formats@.',

	// H
	'hierarchie_site' => 'Gwezennadur al lec’hienn',

	// J
	'jours' => 'deizioù',

	// L
	'lien_connecter' => 'Kevreañ',

	// M
	'meme_auteur' => 'Gant ar skridaozer-mañ',
	'meme_rubrique' => 'Er rubrikenn-mañ',
	'memes_auteurs' => 'Gant ar skridaozerien-mañ',
	'message' => 'Kemennadenn',
	'messages_forum' => 'Kemennadennoù',
	'messages_recents' => 'Kemennadennoù forom diwezhañ',
	'mots_clef' => 'Ger-alc’hwez',
	'mots_clefs' => 'Gerioù-stur',
	'mots_clefs_meme_groupe' => 'Gerioù-stur er strollad-mañ',

	// N
	'navigation' => 'Merdeiñ',
	'nom' => 'Anv',
	'nouveautes' => 'Nevezinti',
	'nouveautes_web' => 'Nevezinti war ar gwiad',
	'nouveaux_articles' => 'Pennadoù nevez',
	'nouvelles_breves' => 'Berrskridoù nevez',

	// P
	'page_precedente' => 'Pajenn kent',
	'page_suivante' => 'Pajenn war-lerc’h',
	'par_auteur' => 'gant',
	'participer_site' => 'Gallout a rit kemer perzh e buhez al lec’hienn ha kinnig pennadoù oc’h emezelañ amañ dindan. Diouzhtu e vo kaset ur postel deoc’h, ennañ ar c’hodoù ret evit dont-tre.',
	'plan_site' => 'Steuñv al lec’hienn',
	'popularite' => 'Brud vat',
	'poster_message' => 'Kas ur gemennadenn',
	'proposer_site' => 'Gallout a rit kinnig ul lec’hienn da ouzhpennañ er rubrikenn-mañ :',

	// R
	'repondre_article' => 'Respont d’ar pennad-mañ',
	'repondre_breve' => 'Respont d’ar berrskrid-mañ',
	'resultats_recherche' => 'Disoc’hoù an enklask',
	'retour_debut_forums' => 'Distreiñ e deroù ar foromoù',
	'rubrique' => 'Rubrikenn',
	'rubriques' => 'Rubrikennoù',

	// S
	'signatures_petition' => 'Sinadurioù',
	'site_realise_avec_spip' => 'Lec’hienn bet savet gant SPIP',
	'sites_web' => 'Lec’hiennoù',
	'sous_rubriques' => 'Isrummadoù',
	'spam' => 'Strob',
	'suite' => 'kenderc’hel',
	'sur_web' => 'War ar Gwiad',
	'syndiquer_rubrique' => 'Sindikadañ ar rubrikenn-mañ',
	'syndiquer_site' => 'Sindikadañ al lec’hienn a-bezh',

	// T
	'texte_lettre_information' => 'Setu lizher kelaouiñ al lec’hienn',
	'texte_lettre_information_2' => 'El lizher-mañ emañ ar pennadoù hag ar berrskridoù embannet abaoe',

	// V
	'ver_imprimer' => 'Stumm da voullañ',
	'voir_en_ligne' => 'Gwelet enlinenn',
	'voir_squelette' => 'Gwelet framm ar bajenn-mañ'
);

?>
